@@ -1,7 +1,9 @@
 package Catalyst::DispatchType::Default;
 
-use strict;
-use base qw/Catalyst::DispatchType/;
+use Moose;
+extends 'Catalyst::DispatchType';
+
+no Moose;
 
 =head1 NAME
 
@@ -9,10 +11,21 @@ Catalyst::DispatchType::Default - Default DispatchType
 
 =head1 SYNOPSIS
 
-See L<Catalyst>.
+See L<Catalyst::DispatchType>.
 
 =head1 DESCRIPTION
 
+Dispatch type managing default behaviour.  For more information on
+dispatch types, see:
+
+=over 4
+
+=item * L<Catalyst::Manual::Intro> for how they affect application authors
+
+=item * L<Catalyst::DispatchType> for implementation information.
+
+=back
+
 =head1 METHODS
 
 =head2 $self->match( $c, $path )
@@ -56,4 +69,6 @@ the same terms as Perl itself.
 
 =cut
 
+__PACKAGE__->meta->make_immutable;
+
 1;
